@@ -911,7 +911,7 @@ class States(object):
                                           category='cultural',
                                           name='admin_1_states_provinces')
         _ = shapereader.Reader(fname)
-        self._records = {x.attributes["iso_3166_2"]: x for x in _.records()}
+        self._records = {x.attributes["iso_3166_2"].replace('\x00', ''): x for x in _.records()}
 
     def __getitem__(self, key):
         return self._records[key]
@@ -923,7 +923,7 @@ class States(object):
         return self._records.items()
 
     def name(self, key):
-        return self[key].attributes["name_en"]
+        return self[key].attributes["name_en"].replace('\x00', '')
 
     def associate(self, data, country=None):
         """
@@ -1032,4 +1032,4 @@ class OriginDestination(object):
                     frst, scnd = label(frst), label(scnd)
                     vv = matrix[frst]
                     vv[scnd] = vv.get(scnd, 0) + 1
-        return matrix
\ No newline at end of file
+        return matrix
